FAN-C command line tools — FAN-C 0.9.1-beta documentation

# FAN-C command line tools

The `fanc` tool should be accessible from the command line after you installed FAN-C (see Installation). It provides convenient commands for the generation, modification, and analysis of Hi-C data.

- Overview and shared parameters
  - Overview
  - Logging
  - Email notifications
  - Temporary files
  - FAN-C config files
- Working with Cooler, Juicer, and text files
  - Cooler `.cool` and `.mcool`
  - Juicer `.hic` files
  - Text files
- Generate Hi-C matrices
  - fanc auto: Automated generation of Hi-C matrices
  - Individual pipeline steps
  - Helper tools
  - Configuration options
- Analyse Hi-C matrices
  - Expected values and O/E matrices
  - AB compartments
  - PCA
  - TADs and TAD boundaries
  - Matrix and score comparisons
  - Aggregate Hi-C matrices
  - Loop calling